'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var theme = require('@chakra-ui/vue-theme');
require('@testing-library/jest-dom');
require('@testing-library/jest-dom/extend-expect');
var vtl = require('@testing-library/vue');
var userEvent = require('@testing-library/user-event');
var vue = require('vue');
var jestAxe = require('jest-axe');

function _interopDefault (e) { return e && e.__esModule ? e : { 'default': e }; }

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n["default"] = e;
  return Object.freeze(n);
}

var theme__default = /*#__PURE__*/_interopDefault(theme);
var vtl__namespace = /*#__PURE__*/_interopNamespace(vtl);
var userEvent__default = /*#__PURE__*/_interopDefault(userEvent);

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

expect.extend(jestAxe.toHaveNoViolations);

var useDefaultProviders = function useDefaultProviders() {
  vue.provide("$chakraTheme", theme__default["default"]);
  vue.provide("$chakraColorMode", "light");
  vue.provide("$chakraIcons", {});
};

/** Render component instance */
var render = function render(component) {
  for (var _len = arguments.length, rest = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    rest[_key - 1] = arguments[_key];
  }

  var utils = vtl__namespace.render.apply(vtl__namespace, [vue.defineComponent({
    name: "ChakraUIVueTestContainer",
    setup: function setup(_, _ref) {
      var slots = _ref.slots;
      useDefaultProviders();
      return function () {
        return vue.h(component, slots);
      };
    }
  })].concat(rest));
  return _extends({}, utils, {
    asFragment: function asFragment(innerHTML) {
      if (innerHTML === void 0) {
        innerHTML = utils.container.innerHTML;
      }

      if (typeof document.createRange === "function") {
        return document.createRange().createContextualFragment(innerHTML);
      }

      var template = document.createElement("template");
      template.innerHTML = innerHTML;
      return template.content;
    }
  });
};
/**
 * Wait for given ms
 *
 * @param {number} duration
 */

function waitMs(ms) {
  if (ms === void 0) {
    ms = 0;
  }

  return new Promise(function (resolve) {
    return setTimeout(resolve, ms);
  });
}
/**
 * Get styles from document.styleSheets
 *
 * @param {String} selector
 *
 * @example className usage
 *  getElementStyles('.anyClassName')
 *
 * @example Emotion Classname
 *  const [className1, className2] = [...screen.getByTestId('aspectRatioBox').classList]
 *  const styles = getElementStyles(`.${className1}`)
 *  const pseudoStyles = getElementStyles(`.${className2}:before`)
 */


function getElementStyles(selector) {
  var _selector = new RegExp(selector);

  var styles = "";
  var i;
  var j;
  var sel = _selector;

  for (i = 0; i < document.styleSheets.length; ++i) {
    for (j = 0; j < document.styleSheets[i].cssRules.length; ++j) {
      var styleRules = document.styleSheets[i].cssRules[j];

      if (sel.test(styleRules.selectorText)) {
        // let selectorText = document.styleSheets[i].cssRules[j].selectorText
        var cssText = styleRules.style.cssText;
        styles += cssText;
      }
    }
  }

  return styles;
}
/**
 * Validates against common a11y mistakes.
 *
 * Wrapper for jest-axe
 *
 * @example
 * ```ts
 * it('passes a11y test', async () => {
 *  await testA11Y(render(MyComponent));
 * });
 *
 * // sometimes we need to perform interactions first to render conditional UI
 * it('passes a11y test when open', async () => {
 *  const { container } = render(MyComponent, options);
 *
 *  fireEvent.click(screen.getByRole('button'));
 *
 *  await testA11Y(container, options);
 * });
 * ```
 */

var testA11y = /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(ui, _temp) {
    var _ref3, axeOptions, template, results;

    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _ref3 = _temp === void 0 ? {} : _temp, axeOptions = _ref3.axeOptions;
            template = ui;

            if ("container" in ui) {
              template = ui.container;
            }

            _context.next = 5;
            return jestAxe.axe(template, axeOptions);

          case 5:
            results = _context.sent;
            expect(results).toHaveNoViolations();

          case 7:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function testA11y(_x, _x2) {
    return _ref2.apply(this, arguments);
  };
}();

Object.defineProperty(exports, 'userEvent', {
  enumerable: true,
  get: function () { return userEvent__default["default"]; }
});
Object.defineProperty(exports, 'axe', {
  enumerable: true,
  get: function () { return jestAxe.axe; }
});
exports.getElementStyles = getElementStyles;
exports.render = render;
exports.testA11y = testA11y;
exports.useDefaultProviders = useDefaultProviders;
exports.waitMs = waitMs;
Object.keys(vtl).forEach(function (k) {
  if (k !== 'default' && !exports.hasOwnProperty(k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return vtl[k]; }
  });
});
